==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/liblxqt/liblxqt_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Search:</source>
        <translation type="vanished">検索:</translation>
    </message>
    <message>
        <source>Add Widget</source>
        <translation type="vanished">ウィジェットを追加</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">閉じる</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
</context>
<context>
    <name>LXQt::AboutDialogPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation type="vanished">バージョン: %1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Qt テクノロジーベースの、高度で使いやすく高速なデスクトップ環境</translation>
    </message>
    <message>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">LXQtは、&lt;a %1&gt;Razor-qt&lt;/a&gt;プロジェクトとそのたくさんの貢献者たちなしにはありえませんでした。</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Copyright: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">ホームページ: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">ライセンス: %1</translation>
    </message>
    <message>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="vanished">LXQtは、&lt;a %1&gt;LXQtチームとその貢献者たち&lt;/a&gt;によって開発されています。</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="vanished">もし私たちの作業に関心がありましたら、&lt;a %1&gt;参加してください&lt;/a&gt;。</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation type="vanished">スペシャルサンクス:</translation>
    </message>
    <message>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation type="vanished">LXQtは、たくさんの言語に翻訳されています。世界各地の翻訳チームの成果に対して謝意を表します。</translation>
    </message>
</context>
<context>
    <name>LXQt::AddPluginDialog</name>
    <message>
        <source>(%1 active)</source>
        <translation type="vanished">(%1 有効)</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt電源管理エラー</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>Hibernate failed.</source>
        <translation>休止の失敗</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>通知のフォールバック</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="112"/>
        <source>Hibernate</source>
        <translation>休止</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="119"/>
        <source>Suspend</source>
        <translation>サスペンド</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="126"/>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="133"/>
        <source>Shutdown</source>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="140"/>
        <source>Logout</source>
        <translation>ログアウト</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="152"/>
        <source>LXQt Session Suspend</source>
        <translation>LXQtセッションのサスペンド</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="153"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>本当にコンピュータをサスペンドしますか？&lt;P&gt;コンピュータを低消費電力状態にサスペンドします。電源が失われた場合にはシステムの状態は保持されません。</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="162"/>
        <source>LXQt Session Hibernate</source>
        <translation>LXQtセッションの休止</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="163"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>本当にコンピュータを休止状態にしますか？&lt;P&gt;コンピュータを
低消費電力状態で休止します。電源が失われた場合でもシステムの状態は保持されます。</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="172"/>
        <source>LXQt Session Reboot</source>
        <translation>LXQtセッションの再起動</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="173"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>本当にコンピュータを再起動しますか？保存されていない作業はすべて失われます...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="182"/>
        <source>LXQt Session Shutdown</source>
        <translation>LXQtセッションのシャットダウン</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="183"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>本当にコンピュータをオフにしたいですか？保存されていないすべての作業は失われます...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="192"/>
        <source>LXQt Session Logout</source>
        <translation>LXQtセッションのログアウト</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="193"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>本当にログアウトしたいですか？保存されていないすべての作業は失われます...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt電源管理エラー</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <source>Hibernate failed.</source>
        <translation>休止の失敗</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Suspend failed.</source>
        <translation>サスペンドの失敗</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="51"/>
        <source>Lock Screen</source>
        <translation>スクリーンをロック</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="77"/>
        <source>Screen Saver Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="83"/>
        <location filename="../../lxqtscreensaver.cpp" line="89"/>
        <location filename="../../lxqtscreensaver.cpp" line="96"/>
        <source>Screen Saver Activation Error</source>
        <translation>スクリーンセーバー起動エラー</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="97"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation type="vanished">スクリーンセーバーの起動時にエラーが発生しました。クラッシュが原因でxdg-スクリーンセーバーを起動できません。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation type="vanished">スクリーンセーバーの起動時にエラーが発生しました。xdg-スクリーンセーバーが正しくインストールされていません。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation type="vanished">スクリーンセーバーの起動時にエラーが発生しました。xdg-スクリーンセーバーを起動できません。</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="78"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>スクリーンセーバーの起動時にエラーが発生しました。xdg-スクリーンセーバーの引数に構文エラーがあります。</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="84"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>スクリーンセーバーの起動時にエラーが発生しました。xscreensaverのインストールと実行を確認してください。</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="90"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>スクリーンセーバーの起動時にエラーが発生しました。&apos;Activate&apos;アクションが失敗しました。xscreensaverのインストールと実行を確認してください。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation type="vanished">スクリーンセーバーを開始する際にエラーが発生しました。不明なエラー - 文書化されていない返り値 xdg-screensaver=%1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
        <source>Power Manager Error</source>
        <translation>電源管理エラー</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDbusInterfaceが無効です。</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>電源マネージャエラー(D-BUSコール)</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About LXQt</source>
        <translation type="vanished">LXQtについて</translation>
    </message>
    <message>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation type="vanished">About</translation>
    </message>
    <message>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">作者</translation>
    </message>
    <message>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">謝辞</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">翻訳</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">技術情報</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="vanished">クリップボードへコピー</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/liblxqt/liblxqt_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Search:</source>
        <translation type="vanished">検索:</translation>
    </message>
    <message>
        <source>Add Widget</source>
        <translation type="vanished">ウィジェットを追加</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">閉じる</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
</context>
<context>
    <name>LXQt::AboutDialogPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation type="vanished">バージョン: %1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Qt テクノロジーベースの、高度で使いやすく高速なデスクトップ環境</translation>
    </message>
    <message>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">LXQtは、&lt;a %1&gt;Razor-qt&lt;/a&gt;プロジェクトとそのたくさんの貢献者たちなしにはありえませんでした。</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Copyright: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">ホームページ: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">ライセンス: %1</translation>
    </message>
    <message>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="vanished">LXQtは、&lt;a %1&gt;LXQtチームとその貢献者たち&lt;/a&gt;によって開発されています。</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="vanished">もし私たちの作業に関心がありましたら、&lt;a %1&gt;参加してください&lt;/a&gt;。</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation type="vanished">スペシャルサンクス:</translation>
    </message>
    <message>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation type="vanished">LXQtは、たくさんの言語に翻訳されています。世界各地の翻訳チームの成果に対して謝意を表します。</translation>
    </message>
</context>
<context>
    <name>LXQt::AddPluginDialog</name>
    <message>
        <source>(%1 active)</source>
        <translation type="vanished">(%1 有効)</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt電源管理エラー</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>Hibernate failed.</source>
        <translation>ハイバーネーションを失敗しました。</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>通知のフォールバック</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="117"/>
        <source>Hibernate</source>
        <translation>休止</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="124"/>
        <source>Suspend</source>
        <translation>サスペンド</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="131"/>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="138"/>
        <source>Shutdown</source>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="145"/>
        <source>Logout</source>
        <translation>ログアウト</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="157"/>
        <source>LXQt Session Suspend</source>
        <translation>LXQtセッションのサスペンド</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="158"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>本当にコンピュータをサスペンドしますか？&lt;P&gt;コンピュータを低消費電力状態にサスペンドします。電源が失われた場合にはシステムの状態は保持されません。</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="167"/>
        <source>LXQt Session Hibernate</source>
        <translation>LXQtセッションの休止</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="168"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>本当にコンピュータを休止状態にしますか？&lt;P&gt;コンピュータを
低消費電力状態で休止します。電源が失われた場合でもシステムの状態は保持されます。</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="177"/>
        <source>LXQt Session Reboot</source>
        <translation>LXQtセッションの再起動</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="178"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>本当にコンピュータを再起動しますか？保存されていない作業はすべて失われます...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="187"/>
        <source>LXQt Session Shutdown</source>
        <translation>LXQtセッションのシャットダウン</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="188"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>本当にコンピュータをオフにしたいですか？保存されていないすべての作業は失われます...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="197"/>
        <source>LXQt Session Logout</source>
        <translation>LXQtセッションのログアウト</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="198"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>本当にログアウトしたいですか？保存されていないすべての作業は失われます...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt電源管理エラー</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Hibernate failed.</source>
        <translation>ハイバーネーションを失敗しました。</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>Suspend failed.</source>
        <translation>サスペンドを失敗しました。</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="236"/>
        <source>Lock Screen</source>
        <translation>スクリーンをロック</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>スクリーンセーバーのエラー</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="162"/>
        <location filename="../../lxqtscreensaver.cpp" line="168"/>
        <location filename="../../lxqtscreensaver.cpp" line="175"/>
        <source>Screen Saver Activation Error</source>
        <translation>スクリーンセーバー起動エラー</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="176"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>スクリーンセーバーの起動時にエラーが発生しました。未知のエラー - undocumented return value from xdg-screensaver: %1.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation type="vanished">スクリーンセーバーの起動時にエラーが発生しました。クラッシュが原因でxdg-スクリーンセーバーを起動できません。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation type="vanished">スクリーンセーバーの起動時にエラーが発生しました。xdg-スクリーンセーバーが正しくインストールされていません。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation type="vanished">スクリーンセーバーの起動時にエラーが発生しました。xdg-スクリーンセーバーを起動できません。</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="157"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>スクリーンセーバーの起動時にエラーが発生しました。xdg-スクリーンセーバーの引数に構文エラーがあります。</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="163"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>スクリーンセーバーの起動時にエラーが発生しました。xscreensaverのインストールと実行を確認してください。</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="169"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>スクリーンセーバーの起動時にエラーが発生しました。&apos;Activate&apos;アクションが失敗しました。xscreensaverのインストールと実行を確認してください。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation type="vanished">スクリーンセーバーを開始する際にエラーが発生しました。不明なエラー - 文書化されていない返り値 xdg-screensaver=%1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>電源管理エラー</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDbusInterfaceが無効です</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>電源マネージャエラー(D-BUSコール)</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About LXQt</source>
        <translation type="vanished">LXQtについて</translation>
    </message>
    <message>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation type="vanished">About</translation>
    </message>
    <message>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">作者</translation>
    </message>
    <message>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">謝辞</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">翻訳</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">技術情報</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="vanished">クリップボードへコピー</translation>
    </message>
</context>
</TS>
